@@ -259,7 +259,7 @@ class DBConnect:
             redundant_filter = param['redundant_dict']  # 额外的数据库筛选字典
             for filter_key, filter_value in redundant_filter.items():
                 # 整理请求参数中的筛选项字典
-                if type(filter_value) == int:
+                if type(filter_value) == int or type(filter_value) == dict:
                     find_dict[filter_key] = filter_value
                 elif filter_key == 'id' or filter_key == '_id':
                     find_dict['_id'] = ObjectId(str(filter_value))
